summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorShobhit Adlakha <adlakhashobhit@gmail.com>2019-03-06 02:08:07 -0500
committerShobhit Adlakha <adlakhashobhit@gmail.com>2019-03-06 02:08:07 -0500
commita4ae4397594e49637c82058749e8465123cea5c9 (patch)
tree8898a3abbde5b41c5266367a931c8de0f8ff5d07
parent2b6b56252391c42a5e0a2009c7777197606d7421 (diff)
downloadsdl_core-feature/app_service_media.tar.gz
Changed RPC name from GetFileFromHMI to GetFilePathfeature/app_service_media
-rw-r--r--src/components/application_manager/rpc_plugins/sdl_rpc_plugin/include/sdl_rpc_plugin/commands/hmi/bc_get_file_path_request.h (renamed from src/components/application_manager/rpc_plugins/sdl_rpc_plugin/include/sdl_rpc_plugin/commands/hmi/bc_get_file_from_hmi_request.h)28
-rw-r--r--src/components/application_manager/rpc_plugins/sdl_rpc_plugin/include/sdl_rpc_plugin/commands/hmi/bc_get_file_path_response.h (renamed from src/components/application_manager/rpc_plugins/sdl_rpc_plugin/include/sdl_rpc_plugin/commands/hmi/bc_get_file_from_hmi_response.h)28
-rw-r--r--src/components/application_manager/rpc_plugins/sdl_rpc_plugin/src/commands/hmi/bc_get_file_path_request.cc (renamed from src/components/application_manager/rpc_plugins/sdl_rpc_plugin/src/commands/hmi/bc_get_file_from_hmi_request.cc)8
-rw-r--r--src/components/application_manager/rpc_plugins/sdl_rpc_plugin/src/commands/hmi/bc_get_file_path_response.cc (renamed from src/components/application_manager/rpc_plugins/sdl_rpc_plugin/src/commands/hmi/bc_get_file_from_hmi_response.cc)10
-rw-r--r--src/components/application_manager/rpc_plugins/sdl_rpc_plugin/src/commands/mobile/get_file_request.cc4
-rw-r--r--src/components/application_manager/rpc_plugins/sdl_rpc_plugin/src/hmi_command_factory.cc10
-rw-r--r--src/components/application_manager/src/hmi_interfaces_impl.cc2
-rw-r--r--src/components/interfaces/HMI_API.xml4
8 files changed, 47 insertions, 47 deletions
diff --git a/src/components/application_manager/rpc_plugins/sdl_rpc_plugin/src/commands/hmi/bc_get_file_from_hmi_request.cc b/src/components/application_manager/rpc_plugins/sdl_rpc_plugin/src/commands/hmi/bc_get_file_path_request.cc
index c1ffb342ec..b735cd9bdf 100644
--- a/src/components/application_manager/rpc_plugins/sdl_rpc_plugin/src/commands/hmi/bc_get_file_from_hmi_request.cc
+++ b/src/components/application_manager/rpc_plugins/sdl_rpc_plugin/src/commands/hmi/bc_get_file_path_request.cc
@@ -30,7 +30,7 @@
POSSIBILITY OF SUCH DAMAGE.
*/
-#include "sdl_rpc_plugin/commands/hmi/bc_get_file_from_hmi_request.h"
+#include "sdl_rpc_plugin/commands/hmi/bc_get_file_path_request.h"
#include "application_manager/application_impl.h"
#include "application_manager/rpc_service.h"
#include "interfaces/MOBILE_API.h"
@@ -39,7 +39,7 @@ namespace sdl_rpc_plugin {
using namespace application_manager;
namespace commands {
-BCGetFileFromHMIRequest::BCGetFileFromHMIRequest(
+BCGetFilePathRequest::BCGetFilePathRequest(
const application_manager::commands::MessageSharedPtr& message,
ApplicationManager& application_manager,
app_mngr::rpc_service::RPCService& rpc_service,
@@ -51,9 +51,9 @@ BCGetFileFromHMIRequest::BCGetFileFromHMIRequest(
hmi_capabilities,
policy_handler) {}
-BCGetFileFromHMIRequest::~BCGetFileFromHMIRequest() {}
+BCGetFilePathRequest::~BCGetFilePathRequest() {}
-void BCGetFileFromHMIRequest::Run() {
+void BCGetFilePathRequest::Run() {
LOG4CXX_AUTO_TRACE(logger_);
SendRequest();
}
diff --git a/src/components/application_manager/rpc_plugins/sdl_rpc_plugin/src/commands/hmi/bc_get_file_from_hmi_response.cc b/src/components/application_manager/rpc_plugins/sdl_rpc_plugin/src/commands/hmi/bc_get_file_path_response.cc
index 3a3b8a5009..b86ab6a2b8 100644
--- a/src/components/application_manager/rpc_plugins/sdl_rpc_plugin/src/commands/hmi/bc_get_file_from_hmi_response.cc
+++ b/src/components/application_manager/rpc_plugins/sdl_rpc_plugin/src/commands/hmi/bc_get_file_path_response.cc
@@ -30,7 +30,7 @@
POSSIBILITY OF SUCH DAMAGE.
*/
-#include "sdl_rpc_plugin/commands/hmi/bc_get_file_from_hmi_response.h"
+#include "sdl_rpc_plugin/commands/hmi/bc_get_file_path_response.h"
#include "application_manager/application_impl.h"
#include "application_manager/rpc_service.h"
#include "interfaces/MOBILE_API.h"
@@ -40,7 +40,7 @@ namespace sdl_rpc_plugin {
using namespace application_manager;
namespace commands {
-BCGetFileFromHMIResponse::BCGetFileFromHMIResponse(
+BCGetFilePathResponse::BCGetFilePathResponse(
const application_manager::commands::MessageSharedPtr& message,
ApplicationManager& application_manager,
app_mngr::rpc_service::RPCService& rpc_service,
@@ -52,12 +52,12 @@ BCGetFileFromHMIResponse::BCGetFileFromHMIResponse(
hmi_capabilities,
policy_handler) {}
-BCGetFileFromHMIResponse::~BCGetFileFromHMIResponse() {}
+BCGetFilePathResponse::~BCGetFilePathResponse() {}
-void BCGetFileFromHMIResponse::Run() {
+void BCGetFilePathResponse::Run() {
LOG4CXX_AUTO_TRACE(logger_);
application_manager::event_engine::Event event(
- hmi_apis::FunctionID::BasicCommunication_GetFileFromHMI);
+ hmi_apis::FunctionID::BasicCommunication_GetFilePath);
event.set_smart_object(*message_);
event.raise(application_manager_.event_dispatcher());
}
diff --git a/src/components/application_manager/rpc_plugins/sdl_rpc_plugin/src/commands/mobile/get_file_request.cc b/src/components/application_manager/rpc_plugins/sdl_rpc_plugin/src/commands/mobile/get_file_request.cc
index 71897d85e9..5c51906368 100644
--- a/src/components/application_manager/rpc_plugins/sdl_rpc_plugin/src/commands/mobile/get_file_request.cc
+++ b/src/components/application_manager/rpc_plugins/sdl_rpc_plugin/src/commands/mobile/get_file_request.cc
@@ -151,7 +151,7 @@ void GetFileRequest::Run() {
if (GetFilePath(file_path, forward_to_hmi)) {
if (forward_to_hmi) {
LOG4CXX_DEBUG(logger_, "Forwarding GetFile request to HMI");
- SendHMIRequest(hmi_apis::FunctionID::BasicCommunication_GetFileFromHMI,
+ SendHMIRequest(hmi_apis::FunctionID::BasicCommunication_GetFilePath,
&(*message_)[strings::msg_params],
true);
return;
@@ -244,7 +244,7 @@ void GetFileRequest::Run() {
void GetFileRequest::on_event(const app_mngr::event_engine::Event& event) {
LOG4CXX_AUTO_TRACE(logger_);
- if (hmi_apis::FunctionID::BasicCommunication_GetFileFromHMI != event.id()) {
+ if (hmi_apis::FunctionID::BasicCommunication_GetFilePath != event.id()) {
return;
}
const smart_objects::SmartObject& event_message = event.smart_object();
diff --git a/src/components/application_manager/rpc_plugins/sdl_rpc_plugin/src/hmi_command_factory.cc b/src/components/application_manager/rpc_plugins/sdl_rpc_plugin/src/hmi_command_factory.cc
index b454cb1cf9..3cfe4d7118 100644
--- a/src/components/application_manager/rpc_plugins/sdl_rpc_plugin/src/hmi_command_factory.cc
+++ b/src/components/application_manager/rpc_plugins/sdl_rpc_plugin/src/hmi_command_factory.cc
@@ -240,8 +240,8 @@
#include "sdl_rpc_plugin/commands/hmi/rc_is_ready_response.h"
#include "sdl_rpc_plugin/commands/hmi/rc_get_capabilities_request.h"
#include "sdl_rpc_plugin/commands/hmi/rc_get_capabilities_response.h"
-#include "sdl_rpc_plugin/commands/hmi/bc_get_file_from_hmi_request.h"
-#include "sdl_rpc_plugin/commands/hmi/bc_get_file_from_hmi_response.h"
+#include "sdl_rpc_plugin/commands/hmi/bc_get_file_path_request.h"
+#include "sdl_rpc_plugin/commands/hmi/bc_get_file_path_response.h"
#include "sdl_rpc_plugin/commands/hmi/on_bc_system_capability_updated_notification.h"
@@ -844,10 +844,10 @@ CommandCreator& HMICommandFactory::get_creator_factory(
? factory.GetCreator<commands::UISendHapticDataRequest>()
: factory.GetCreator<commands::UISendHapticDataResponse>();
}
- case hmi_apis::FunctionID::BasicCommunication_GetFileFromHMI: {
+ case hmi_apis::FunctionID::BasicCommunication_GetFilePath: {
return hmi_apis::messageType::request == message_type
- ? factory.GetCreator<commands::BCGetFileFromHMIRequest>()
- : factory.GetCreator<commands::BCGetFileFromHMIResponse>();
+ ? factory.GetCreator<commands::BCGetFilePathRequest>()
+ : factory.GetCreator<commands::BCGetFilePathResponse>();
}
case hmi_apis::FunctionID::BasicCommunication_OnSystemCapabilityUpdated: {
return factory
diff --git a/src/components/application_manager/src/hmi_interfaces_impl.cc b/src/components/application_manager/src/hmi_interfaces_impl.cc
index a4d6b82128..9aff403e09 100644
--- a/src/components/application_manager/src/hmi_interfaces_impl.cc
+++ b/src/components/application_manager/src/hmi_interfaces_impl.cc
@@ -103,7 +103,7 @@ generate_function_to_interface_convert_map() {
HmiInterfaces::HMI_INTERFACE_BasicCommunication;
convert_map[BasicCommunication_OnEventChanged] =
HmiInterfaces::HMI_INTERFACE_BasicCommunication;
- convert_map[BasicCommunication_GetFileFromHMI] =
+ convert_map[BasicCommunication_GetFilePath] =
HmiInterfaces::HMI_INTERFACE_BasicCommunication;
convert_map[VR_IsReady] = HmiInterfaces::HMI_INTERFACE_VR;
convert_map[VR_Started] = HmiInterfaces::HMI_INTERFACE_VR;
diff --git a/src/components/interfaces/HMI_API.xml b/src/components/interfaces/HMI_API.xml
index ada1c837ab..8f77a9dd68 100644
--- a/src/components/interfaces/HMI_API.xml
+++ b/src/components/interfaces/HMI_API.xml
@@ -4179,7 +4179,7 @@
</param>
</function>
- <function name="GetFileFromHMI" messagetype="request">
+ <function name="GetFilePath" messagetype="request">
<description>This request is sent to retrieve a file path from the HMI.</description>
<param name="fileName" type="String" maxlength="255" mandatory="true">
<description>File name that should be retrieved.</description>
@@ -4191,7 +4191,7 @@
<description> ID of the service that should have uploaded the requested file.</description>
</param>
</function>
- <function name="GetFileFromHMI" messagetype="response">
+ <function name="GetFilePath" messagetype="response">
<description> HMI handles the request internally and returns the file path with the response.</description>
<param name="filePath" type="String" mandatory="false">
<description>Path to file in hmi</description>
diff --git a/src/components/application_manager/rpc_plugins/sdl_rpc_plugin/include/sdl_rpc_plugin/commands/hmi/bc_get_file_from_hmi_request.h b/src/components/application_manager/rpc_plugins/sdl_rpc_plugin/include/sdl_rpc_plugin/commands/hmi/bc_get_file_path_request.h
index ff764e1e85..fd241da3c4 100644
--- a/src/components/application_manager/rpc_plugins/sdl_rpc_plugin/include/sdl_rpc_plugin/commands/hmi/bc_get_file_from_hmi_request.h
+++ b/src/components/application_manager/rpc_plugins/sdl_rpc_plugin/include/sdl_rpc_plugin/commands/hmi/bc_get_file_path_request.h
@@ -30,8 +30,8 @@
POSSIBILITY OF SUCH DAMAGE.
*/
-#ifndef SRC_COMPONENTS_APPLICATION_MANAGER_RPC_PLUGINS_SDL_RPC_PLUGIN_INCLUDE_SDL_RPC_PLUGIN_COMMANDS_HMI_BC_GET_FILE_FROM_HMI_REQUEST_H_
-#define SRC_COMPONENTS_APPLICATION_MANAGER_RPC_PLUGINS_SDL_RPC_PLUGIN_INCLUDE_SDL_RPC_PLUGIN_COMMANDS_HMI_BC_GET_FILE_FROM_HMI_REQUEST_H_
+#ifndef SRC_COMPONENTS_APPLICATION_MANAGER_RPC_PLUGINS_SDL_RPC_PLUGIN_INCLUDE_SDL_RPC_PLUGIN_COMMANDS_HMI_BC_GET_FILE_PATH_REQUEST_H_
+#define SRC_COMPONENTS_APPLICATION_MANAGER_RPC_PLUGINS_SDL_RPC_PLUGIN_INCLUDE_SDL_RPC_PLUGIN_COMMANDS_HMI_BC_GET_FILE_PATH_REQUEST_H_
#include "application_manager/commands/request_to_hmi.h"
@@ -41,25 +41,25 @@ namespace app_mngr = application_manager;
namespace commands {
/**
* @brief BCGetFileFromHMIRequest command class
**/
-class BCGetFileFromHMIRequest : public app_mngr::commands::RequestToHMI {
+class BCGetFilePathRequest : public app_mngr::commands::RequestToHMI {
public:
/**
* @brief BCGetFileFromHMIRequest class constructor
*
* @param message Incoming SmartObject message
**/
- BCGetFileFromHMIRequest(const app_mngr::commands::MessageSharedPtr& message,
- app_mngr::ApplicationManager& application_manager,
- app_mngr::rpc_service::RPCService& rpc_service,
- app_mngr::HMICapabilities& hmi_capabilities,
- policy::PolicyHandlerInterface& policy_handler);
+ BCGetFilePathRequest(const app_mngr::commands::MessageSharedPtr& message,
+ app_mngr::ApplicationManager& application_manager,
+ app_mngr::rpc_service::RPCService& rpc_service,
+ app_mngr::HMICapabilities& hmi_capabilities,
+ policy::PolicyHandlerInterface& policy_handler);
/**
* @brief BCGetFileFromHMIRequest class destructor
**/
- virtual ~BCGetFileFromHMIRequest();
+ virtual ~BCGetFilePathRequest();
/**
* @brief Execute command
@@ -67,11 +67,11 @@ class BCGetFileFromHMIRequest : public app_mngr::commands::RequestToHMI {
virtual void Run();
private:
- DISALLOW_COPY_AND_ASSIGN(BCGetFileFromHMIRequest);
+ DISALLOW_COPY_AND_ASSIGN(BCGetFilePathRequest);
};
} // namespace commands
} // namespace sdl_rpc_plugin
-#endif // SRC_COMPONENTS_APPLICATION_MANAGER_RPC_PLUGINS_sdl_RPC_PLUGIN_INCLUDE_sdl_RPC_PLUGIN_COMMANDS_HMI_BC_GET_FILE_FROM_HMI_REQUEST_H_
+#endif // SRC_COMPONENTS_APPLICATION_MANAGER_RPC_PLUGINS_sdl_RPC_PLUGIN_INCLUDE_sdl_RPC_PLUGIN_COMMANDS_HMI_BC_GET_FILE_PATH_REQUEST_H_
@@ -41,25 +41,25 @@ namespace app_mngr = application_manager;
namespace commands {
/**
- * @brief BCGetFileFromHMIRequest command class
+ * @brief BCGetFilePathRequest command class
**/
@@ -41,25 +41,25 @@ namespace app_mngr = application_manager;
public:
/**
- * @brief BCGetFileFromHMIRequest class constructor
+ * @brief BCGetFilePathRequest class constructor
*
* @param message Incoming SmartObject message
@@ -41,25 +41,25 @@ namespace app_mngr = application_manager;
/**
- * @brief BCGetFileFromHMIRequest class destructor
+ * @brief BCGetFilePathRequest class destructor
**/
diff --git a/src/components/application_manager/rpc_plugins/sdl_rpc_plugin/include/sdl_rpc_plugin/commands/hmi/bc_get_file_from_hmi_response.h b/src/components/application_manager/rpc_plugins/sdl_rpc_plugin/include/sdl_rpc_plugin/commands/hmi/bc_get_file_path_response.h
index 6b27f2d9a7..2a6025cbdf 100644
--- a/src/components/application_manager/rpc_plugins/sdl_rpc_plugin/include/sdl_rpc_plugin/commands/hmi/bc_get_file_from_hmi_response.h
+++ b/src/components/application_manager/rpc_plugins/sdl_rpc_plugin/include/sdl_rpc_plugin/commands/hmi/bc_get_file_path_response.h
@@ -30,8 +30,8 @@
POSSIBILITY OF SUCH DAMAGE.
*/
-#ifndef SRC_COMPONENTS_APPLICATION_MANAGER_RPC_PLUGINS_SDL_RPC_PLUGIN_INCLUDE_SDL_RPC_PLUGIN_COMMANDS_HMI_BC_GET_FILE_FROM_HMI_RESPONSE_H_
-#define SRC_COMPONENTS_APPLICATION_MANAGER_RPC_PLUGINS_SDL_RPC_PLUGIN_INCLUDE_SDL_RPC_PLUGIN_COMMANDS_HMI_BC_GET_FILE_FROM_HMI_RESPONSE_H_
+#ifndef SRC_COMPONENTS_APPLICATION_MANAGER_RPC_PLUGINS_SDL_RPC_PLUGIN_INCLUDE_SDL_RPC_PLUGIN_COMMANDS_HMI_BC_GET_FILE_PATH_RESPONSE_H_
+#define SRC_COMPONENTS_APPLICATION_MANAGER_RPC_PLUGINS_SDL_RPC_PLUGIN_INCLUDE_SDL_RPC_PLUGIN_COMMANDS_HMI_BC_GET_FILE_PATH_RESPONSE_H_
#include "application_manager/commands/response_from_hmi.h"
@@ -41,25 +41,25 @@ namespace app_mngr = application_manager;
namespace commands {
/**
* @brief BCGetFileFromHMIResponse command class
**/
-class BCGetFileFromHMIResponse : public app_mngr::commands::ResponseFromHMI {
+class BCGetFilePathResponse : public app_mngr::commands::ResponseFromHMI {
public:
/**
* @brief BCGetFileFromHMIResponse class constructor
*
* @param message Incoming SmartObject message
**/
- BCGetFileFromHMIResponse(const app_mngr::commands::MessageSharedPtr& message,
- app_mngr::ApplicationManager& application_manager,
- app_mngr::rpc_service::RPCService& rpc_service,
- app_mngr::HMICapabilities& hmi_capabilities,
- policy::PolicyHandlerInterface& policy_handler);
+ BCGetFilePathResponse(const app_mngr::commands::MessageSharedPtr& message,
+ app_mngr::ApplicationManager& application_manager,
+ app_mngr::rpc_service::RPCService& rpc_service,
+ app_mngr::HMICapabilities& hmi_capabilities,
+ policy::PolicyHandlerInterface& policy_handler);
/**
* @brief BCGetFileFromHMIResponse class destructor
**/
- virtual ~BCGetFileFromHMIResponse();
+ virtual ~BCGetFilePathResponse();
/**
* @brief Execute command
@@ -67,11 +67,11 @@ class BCGetFileFromHMIResponse : public app_mngr::commands::ResponseFromHMI {
virtual void Run();
private:
- DISALLOW_COPY_AND_ASSIGN(BCGetFileFromHMIResponse);
+ DISALLOW_COPY_AND_ASSIGN(BCGetFilePathResponse);
};
} // namespace commands
} // namespace sdl_rpc_plugin
-#endif // SRC_COMPONENTS_APPLICATION_MANAGER_RPC_PLUGINS_SDL_RPC_PLUGIN_INCLUDE_SDL_RPC_PLUGIN_COMMANDS_HMI_BC_GET_FILE_FROM_HMI_RESPONSE_H_
+#endif // SRC_COMPONENTS_APPLICATION_MANAGER_RPC_PLUGINS_SDL_RPC_PLUGIN_INCLUDE_SDL_RPC_PLUGIN_COMMANDS_HMI_BC_GET_FILE_PATH_RESPONSE_H_
@@ -41,25 +41,25 @@ namespace app_mngr = application_manager;
namespace commands {
/**
- * @brief BCGetFileFromHMIResponse command class
+ * @brief BCGetFilePathResponse command class
**/
@@ -41,25 +41,25 @@ namespace app_mngr = application_manager;
public:
/**
- * @brief BCGetFileFromHMIResponse class constructor
+ * @brief BCGetFilePathResponse class constructor
*
* @param message Incoming SmartObject message
@@ -41,25 +41,25 @@ namespace app_mngr = application_manager;
/**
- * @brief BCGetFileFromHMIResponse class destructor
+ * @brief BCGetFilePathResponse class destructor
**/